/*
 * lib.h -- a small library for various parts of nash
 *
 * Copyright 2006-2008 Red Hat, Inc.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author(s): Peter Jones <pjones@redhat.com>
 */

#ifndef NASH_PRIV_LIB_H
#define NASH_PRIV_LIB_H 1

#ifdef _GNU_SOURCE
#define _GNU_SOURCE_DEFINED
#else
#define _GNU_SOURCE 1
#endif

#include <nash.h>
#include <signal.h>
#include <blkid/blkid.h>

#include "util.h"
#include "list.h"
#include "dict.h"
#include "procdev.h"
#include "devtree.h"
#include "vitals.h"
#include "blkent.h"
#include "block.h"
#include "adler32.h"

struct nashDevice;

struct nashContext_s {
    nashLogger_t logger;
    int testing;
    int quiet;
    int reallyquiet;

    blkid_cache cache;

    nashFileFetcher_t fetcher;
    char *fw_pathz;
    size_t fw_pathz_len;

    nashDelayFunction_t delayParent;
    int hp_parent_pid;
    int hp_child_pid;

    int hp_parentfd;
    int hp_childfd;

    struct nash_proc_dev_cache *pdc; /* /proc/devices cache */
    struct nash_uevent_handler *uh;

    struct nash_vitals_cache *vitals;
    struct nash_dev_tree *devices;
    struct nash_dev_tree *blktab;

    nashBdevIter waitdev_iter;
};

extern int nashWaitForDevice(nashContext *, char *device, long long timeout);

#ifndef _GNU_SOURCE_DEFINED
#undef _GNU_SOURCE
#else
#undef _GNU_SOURCE_DEFINED
#endif

#endif /* NASH_PRIV_LIB_H */
/*
 * vim:ts=8:sw=4:sts=4:et
 */
